==> mx-packageinstaller-pkglist_19.07.01.tar.xz: mx-packageinstaller-pkglist/dutch.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Dutch
</name>

<description>
   <am>Dutch Language Meta-Package</am>
   <ar>Dutch Language Meta-Package</ar>
   <bg>Dutch Language Meta-Package</bg>
   <ca>Meta-paquet per llengua Holandesa</ca>
   <cs>Dutch Language Meta-Package</cs>
   <da>Hollandsk sprog-metapakke</da>
   <de>Niederländisches Sprach-Meta-Paket</de>
   <el>Ολλανδική γλώσσα</el>
   <en>Dutch Language Meta-Package</en>
   <es>Dutch Language Meta-Package</es>
   <et>Dutch Language Meta-Package</et>
   <eu>Dutch Language Meta-Package</eu>
   <fa>Dutch Language Meta-Package</fa>
   <fi>Dutch Language Meta-Package</fi>
   <fr>Méta-Paquet langue néerlandaise</fr>
   <he_IL>Dutch Language Meta-Package</he_IL>
   <hi>Dutch Language Meta-Package</hi>
   <hr>Dutch Language Meta-Package</hr>
   <hu>Dutch Language Meta-Package</hu>
   <id>Dutch Language Meta-Package</id>
   <is>Dutch Language Meta-Package</is>
   <it>Meta-pacchetto della lingua olandese</it>
   <ja_JP>Dutch Language Meta-Package</ja_JP>
   <ja>Dutch Language Meta-Package</ja>
   <kk>Dutch Language Meta-Package</kk>
   <ko>Dutch Language Meta-Package</ko>
   <lt>Dutch Language Meta-Package</lt>
   <mk>Dutch Language Meta-Package</mk>
   <nb>Dutch Language Meta-Package</nb>
   <nl>Nederlandse Taal Meta-Pakket</nl>
   <pl>Holenderski metapakiet językowy</pl>
   <pt_BR>Holandês Meta-Pacote de Idioma</pt_BR>
   <pt>Holandês Meta-Pacote de Idioma</pt>
   <ro>Dutch Language Meta-Package</ro>
   <ru>Dutch Language Meta-Package</ru>
   <sk>Dutch Language Meta-Package</sk>
   <sl>Dutch Language Meta-Package</sl>
   <sq>Dutch Language Meta-Package</sq>
   <sr>Dutch Language Meta-Package</sr>
   <sv>Holländska språket Meta-Paket</sv>
   <tr>Dutch Language Meta-Package</tr>
   <uk>Dutch Language Meta-Package</uk>
   <zh_CN>Dutch Language Meta-Package</zh_CN>
   <zh_TW>Dutch Language Meta-Package</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
aspell-nl
myspell-nl
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
aspell-nl
myspell-nl
</uninstall_package_names>
</app>

==> mx-packageinstaller-pkglist_19.09.03.tar.xz: mx-packageinstaller-pkglist/dutch.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Dutch
</name>

<description>
   <am>Dutch Language Meta-Package</am>
   <ar>Dutch Language Meta-Package</ar>
   <bg>Dutch Language Meta-Package</bg>
   <ca>Meta-paquet per llengua Holandesa</ca>
   <cs>Dutch Language Meta-Package</cs>
   <da>Hollandsk sprog-metapakke</da>
   <de>Niederländisches Sprach-Meta-Paket</de>
   <el>Ολλανδική γλώσσα</el>
   <en>Dutch Language Meta-Package</en>
   <es>Meta-Paquete de Idioma Holandés</es>
   <et>Dutch Language Meta-Package</et>
   <eu>Dutch Language Meta-Package</eu>
   <fa>Dutch Language Meta-Package</fa>
   <fi>Dutch Language Meta-Package</fi>
   <fr>Méta-Paquet langue néerlandaise</fr>
   <he_IL>Dutch Language Meta-Package</he_IL>
   <hi>Dutch Language Meta-Package</hi>
   <hr>Dutch Language Meta-Package</hr>
   <hu>Dutch Language Meta-Package</hu>
   <id>Dutch Language Meta-Package</id>
   <is>Dutch Language Meta-Package</is>
   <it>Meta-pacchetto della lingua olandese</it>
   <ja_JP>Dutch Language Meta-Package</ja_JP>
   <ja>Dutch Language Meta-Package</ja>
   <kk>Dutch Language Meta-Package</kk>
   <ko>Dutch Language Meta-Package</ko>
   <lt>Dutch Language Meta-Package</lt>
   <mk>Dutch Language Meta-Package</mk>
   <nb>Dutch Language Meta-Package</nb>
   <nl>Nederlandse Taal Meta-Pakket</nl>
   <pl>Holenderski metapakiet językowy</pl>
   <pt_BR>Holandês Meta-Pacote de Idioma</pt_BR>
   <pt>Holandês Meta-Pacote de Idioma</pt>
   <ro>Dutch Language Meta-Package</ro>
   <ru>Dutch Language Meta-Package</ru>
   <sk>Dutch Language Meta-Package</sk>
   <sl>Dutch Language Meta-Package</sl>
   <sq>Dutch Language Meta-Package</sq>
   <sr>Dutch Language Meta-Package</sr>
   <sv>Holländska språket Meta-Paket</sv>
   <tr>Dutch Language Meta-Package</tr>
   <uk>Dutch Language Meta-Package</uk>
   <zh_CN>Dutch Language Meta-Package</zh_CN>
   <zh_TW>Dutch Language Meta-Package</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
aspell-nl
hunspell-nl
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
aspell-nl
hunspell-nl
</uninstall_package_names>
</app>
